pub struct NuLazyFrameCustomValue {
pub id: Uuid,
pub lazyframe: Option<NuLazyFrame>,
}Fields
id: Uuidlazyframe: Option<NuLazyFrame>Trait Implementations
Sourceimpl Clone for NuLazyFrameCustomValue
impl Clone for NuLazyFrameCustomValue
Sourcefn clone(&self) -> NuLazyFrameCustomValue
fn clone(&self) -> NuLazyFrameCustomValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomValue for NuLazyFrameCustomValue
impl CustomValue for NuLazyFrameCustomValue
Sourcefn type_name(&self) -> String
fn type_name(&self) -> String
The friendly type name to show for the custom value, e.g. in
describe and in error
messages. This does not have to be the same as the name of the struct or enum, but
conventionally often is.Sourcefn to_base_value(&self, span: Span) -> Result<Value, ShellError>
fn to_base_value(&self, span: Span) -> Result<Value, ShellError>
Converts the custom value to a base nushell value. Read more
Sourcefn as_mut_any(&mut self) -> &mut dyn Any
fn as_mut_any(&mut self) -> &mut dyn Any
Any representation used to downcast object to its original type (mutable reference)
Sourcefn notify_plugin_on_drop(&self) -> bool
fn notify_plugin_on_drop(&self) -> bool
For custom values in plugins: return
true here if you would like to be notified when all
copies of this custom value are dropped in the engine. Read moreSourcefn follow_path_int(
&self,
self_span: Span,
index: usize,
path_span: Span,
optional: bool,
) -> Result<Value, ShellError>
fn follow_path_int( &self, self_span: Span, index: usize, path_span: Span, optional: bool, ) -> Result<Value, ShellError>
Follow cell path by numeric index (e.g. rows). Read more
Sourcefn follow_path_string(
&self,
self_span: Span,
column_name: String,
path_span: Span,
optional: bool,
casing: Casing,
) -> Result<Value, ShellError>
fn follow_path_string( &self, self_span: Span, column_name: String, path_span: Span, optional: bool, casing: Casing, ) -> Result<Value, ShellError>
Follow cell path by string key (e.g. columns). Read more
Sourcefn partial_cmp(&self, _other: &Value) -> Option<Ordering>
fn partial_cmp(&self, _other: &Value) -> Option<Ordering>
ordering with other value (see
std::cmp::PartialOrd)Sourcefn operation(
&self,
lhs_span: Span,
operator: Operator,
op: Span,
right: &Value,
) -> Result<Value, ShellError>
fn operation( &self, lhs_span: Span, operator: Operator, op: Span, right: &Value, ) -> Result<Value, ShellError>
Definition of an operation between the object that implements the trait
and another Value. Read more
Sourcefn save(
&self,
path: Spanned<&Path>,
value_span: Span,
save_span: Span,
) -> Result<(), ShellError>
fn save( &self, path: Spanned<&Path>, value_span: Span, save_span: Span, ) -> Result<(), ShellError>
Save custom value to disk. Read more
Sourcefn memory_size(&self) -> usize
fn memory_size(&self) -> usize
Returns an estimate of the memory size used by this CustomValue in bytes Read more
Sourcefn is_iterable(&self) -> bool
fn is_iterable(&self) -> bool
Returns
true if this custom value should be iterable (like a list) when used with
commands like each, where, etc. Read moreSourceimpl Debug for NuLazyFrameCustomValue
impl Debug for NuLazyFrameCustomValue
Sourceimpl<'de> Deserialize<'de> for NuLazyFrameCustomValue
impl<'de> Deserialize<'de> for NuLazyFrameCustomValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PolarsPluginCustomValue for NuLazyFrameCustomValue
impl PolarsPluginCustomValue for NuLazyFrameCustomValue
type PolarsPluginObjectType = NuLazyFrame
fn custom_value_to_base_value( &self, plugin: &PolarsPlugin, _engine: &EngineInterface, ) -> Result<Value, ShellError>
fn id(&self) -> &Uuid
fn internal(&self) -> &Option<Self::PolarsPluginObjectType>
fn custom_value_partial_cmp( &self, plugin: &PolarsPlugin, _engine: &EngineInterface, other_value: Value, ) -> Result<Option<Ordering>, ShellError>
fn custom_value_operation( &self, plugin: &PolarsPlugin, engine: &EngineInterface, lhs_span: Span, operator: Spanned<Operator>, right: Value, ) -> Result<Value, ShellError>
fn custom_value_follow_path_int( &self, plugin: &PolarsPlugin, engine: &EngineInterface, _self_span: Span, index: Spanned<usize>, ) -> Result<Value, ShellError>
fn custom_value_follow_path_string( &self, plugin: &PolarsPlugin, engine: &EngineInterface, _self_span: Span, column_name: Spanned<String>, ) -> Result<Value, ShellError>